package org.bouncycastle.tls;

public class CertificateStatusType
{
    /*
     *  RFC 6066
     */
    public static final short ocsp = 1;

    /*
     *  RFC 6961
     */
    public static final short ocsp_multi = 2;
}
